==> nextcloud-15.0.10.tar.bz2: nextcloud/apps/accessibility/l10n/ro.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Temă cu contrast înalt",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Temă cu contrast înalt pentru ușurarea navigării. Calitatea visuală va fi redusă dar claritatea va fi mărită.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Temă întunecată pentru ușurarea ochilor prin reducerea generală a luminozității. Temă în curs de dezvoltare deci vă rugăm să raportați orice problemă găsită.",
    "Dyslexia font" : "Font dislexic",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic este un tip de caractere / font gratuit destinat să atenueze unele erori comune de citire cauzate de dislexie.",
    "Accessibility" : "Accesibilitate",
    "Accessibility options for nextcloud" : "Opțiuni de accesibilitate pentru nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Vă oferă opțiuni multiple de accesibilitate pentru a simplifica utilizarea Nextcloud",
    "Web Content Accessibility Guidelines" : "Instrucțiuni privind accesibilitatea conținutului web",
    "our issue tracker" : "instrumentul nostru de urmărire a problemelor",
    "our design team" : "echipa noastră de design",
    "Enable" : "Activează",
    "Dark theme (beta)" : "Temă întunecată (beta)"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-15.0.11.tar.bz2: nextcloud/apps/accessibility/l10n/ro.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Temă cu contrast înalt",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Temă cu contrast înalt pentru ușurarea navigării. Calitatea visuală va fi redusă dar claritatea va fi mărită.",
    "Dark theme" : "Temă întunecată",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Temă întunecată pentru ușurarea ochilor prin reducerea generală a luminozității. Temă în curs de dezvoltare deci vă rugăm să raportați orice problemă găsită.",
    "Dyslexia font" : "Font dislexic",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic este un tip de caractere / font gratuit destinat să atenueze unele erori comune de citire cauzate de dislexie.",
    "Accessibility" : "Accesibilitate",
    "Accessibility options for nextcloud" : "Opțiuni de accesibilitate pentru nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Vă oferă opțiuni multiple de accesibilitate pentru a simplifica utilizarea Nextcloud",
    "Web Content Accessibility Guidelines" : "Instrucțiuni privind accesibilitatea conținutului web",
    "our issue tracker" : "instrumentul nostru de urmărire a problemelor",
    "our design team" : "echipa noastră de design",
    "Enable" : "Activează",
    "Dark theme (beta)" : "Temă întunecată (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic este un set de caractere / font gratuit destinat să atenueze unele erori comune de citire cauzate de dislexie. Setul de caractere a fost creat de Abelardo Gonzalez, care a fost publicat sub o licență open-source.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Oferă mai multe opțiuni de accesibilitate pentru a ușura utilizarea Nextcloud",
    "Themes" : "Teme",
    "Fonts" : "Fonturi",
    "enabled" : "activat"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
